@@ -76,7 +76,7 @@ diversity <- function (A, comm = c("walktrap","louvain"))
         Snm <- matrix(0,nrow=n,ncol=m)
         
         for(i in 1:m)
-        {Snm[,i] <- rowSums(A[,facts==i])}
+        {Snm[,i] <- rowSums(A[,which(facts==i)])}
         
         pnm <- Snm/(S*matrix(1,nrow=n,ncol=m))
         pnm[is.na(pnm)]<-0
